#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

GOM(vdp_device_create_x11, iFpipp) // last is a pointer to a VdpGetProcAddress function